@@ -1,11 +1,13 @@
 import os
 import sys
 from uniton.util import user_data_dir
+import shutil
+
 
 def cmd_delete_data():
-  raise NotImplementedError()
   print("deleting all user data")
-  # TODO: implement
+  d = user_data_dir('Uniton')
+  shutil.rmtree(d, ignore_errors=True)
 
 def cmd_open_data_dir():
   os.system(f"open '{user_data_dir('Uniton')}'")
